@@ -1,6 +1,6 @@
-from .cmd_init import init
-from .cmd_run import run
-from .cmd_plug import plug
 from .cmd_conf import conf
+from .cmd_init import init
+from .cmd_plug import plug
+from .cmd_run import run
 
-__all__ = ["init", "run", "plug", "conf"]
+__all__ = ["conf", "init", "plug", "run"]
