@@ -1,31 +1,33 @@
 import sys
 import traceback
 import typing as T
-from .base import BaseAgentRunner, AgentResponse, AgentState
-from ..hooks import BaseAgentRunHooks
-from ..tool_executor import BaseFunctionToolExecutor
-from ..run_context import ContextWrapper, TContext
-from ..response import AgentResponseData
-from astrbot.core.provider.provider import Provider
+
+from mcp.types import (
+    BlobResourceContents,
+    CallToolResult,
+    EmbeddedResource,
+    ImageContent,
+    TextContent,
+    TextResourceContents,
+)
+
+from astrbot import logger
 from astrbot.core.message.message_event_result import (
     MessageChain,
 )
 from astrbot.core.provider.entities import (
-    ProviderRequest,
     LLMResponse,
-    ToolCallMessageSegment,
-    AssistantMessageSegment,
+    ProviderRequest,
     ToolCallsResult,
 )
-from mcp.types import (
-    TextContent,
-    ImageContent,
-    EmbeddedResource,
-    TextResourceContents,
-    BlobResourceContents,
-    CallToolResult,
-)
-from astrbot import logger
+from astrbot.core.provider.provider import Provider
+
+from ..hooks import BaseAgentRunHooks
+from ..message import AssistantMessageSegment, ToolCallMessageSegment
+from ..response import AgentResponseData
+from ..run_context import ContextWrapper, TContext
+from ..tool_executor import BaseFunctionToolExecutor
+from .base import AgentResponse, AgentState, BaseAgentRunner
 
 if sys.version_info >= (3, 12):
     from typing import override
@@ -70,8 +72,7 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
 
     @override
     async def step(self):
-        """
-        Process a single step of the agent.
+        """Process a single step of the agent.
         This method should return the result of the step.
         """
         if not self.req:
@@ -99,7 +100,7 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                     yield AgentResponse(
                         type="streaming_delta",
                         data=AgentResponseData(
-                            chain=MessageChain().message(llm_response.completion_text)
+                            chain=MessageChain().message(llm_response.completion_text),
                         ),
                     )
                 continue
@@ -120,8 +121,8 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                 type="err",
                 data=AgentResponseData(
                     chain=MessageChain().message(
-                        f"LLM 响应错误: {llm_resp.completion_text or '未知错误'}"
-                    )
+                        f"LLM 响应错误: {llm_resp.completion_text or '未知错误'}",
+                    ),
                 ),
             )
 
@@ -144,7 +145,7 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
             yield AgentResponse(
                 type="llm_result",
                 data=AgentResponseData(
-                    chain=MessageChain().message(llm_resp.completion_text)
+                    chain=MessageChain().message(llm_resp.completion_text),
                 ),
             )
 
@@ -155,7 +156,7 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                 yield AgentResponse(
                     type="tool_call",
                     data=AgentResponseData(
-                        chain=MessageChain().message(f"🔨 调用工具: {tool_call_name}")
+                        chain=MessageChain().message(f"🔨 调用工具: {tool_call_name}"),
                     ),
                 )
             async for result in self._handle_function_tools(self.req, llm_resp):
@@ -169,8 +170,7 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
             # 将结果添加到上下文中
             tool_calls_result = ToolCallsResult(
                 tool_calls_info=AssistantMessageSegment(
-                    role="assistant",
-                    tool_calls=llm_resp.to_openai_tool_calls(),
+                    tool_calls=llm_resp.to_openai_to_calls_model(),
                     content=llm_resp.completion_text,
                 ),
                 tool_calls_result=tool_call_result_blocks,
@@ -198,9 +198,50 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                 func_tool = req.func_tool.get_func(func_tool_name)
                 logger.info(f"使用工具：{func_tool_name}，参数：{func_tool_args}")
 
+                if not func_tool:
+                    logger.warning(f"未找到指定的工具: {func_tool_name}，将跳过。")
+                    tool_call_result_blocks.append(
+                        ToolCallMessageSegment(
+                            role="tool",
+                            tool_call_id=func_tool_id,
+                            content=f"error: 未找到工具 {func_tool_name}",
+                        ),
+                    )
+                    continue
+
+                valid_params = {}  # 参数过滤：只传递函数实际需要的参数
+
+                # 获取实际的 handler 函数
+                if func_tool.handler:
+                    logger.debug(
+                        f"工具 {func_tool_name} 期望的参数: {func_tool.parameters}",
+                    )
+                    if func_tool.parameters and func_tool.parameters.get("properties"):
+                        expected_params = set(func_tool.parameters["properties"].keys())
+
+                        valid_params = {
+                            k: v
+                            for k, v in func_tool_args.items()
+                            if k in expected_params
+                        }
+
+                    # 记录被忽略的参数
+                    ignored_params = set(func_tool_args.keys()) - set(
+                        valid_params.keys(),
+                    )
+                    if ignored_params:
+                        logger.warning(
+                            f"工具 {func_tool_name} 忽略非期望参数: {ignored_params}",
+                        )
+                else:
+                    # 如果没有 handler（如 MCP 工具），使用所有参数
+                    valid_params = func_tool_args
+
                 try:
                     await self.agent_hooks.on_tool_start(
-                        self.run_context, func_tool, func_tool_args
+                        self.run_context,
+                        func_tool,
+                        valid_params,
                     )
                 except Exception as e:
                     logger.error(f"Error in on_tool_start hook: {e}", exc_info=True)
@@ -208,18 +249,21 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                 executor = self.tool_executor.execute(
                     tool=func_tool,
                     run_context=self.run_context,
-                    **func_tool_args,
+                    **valid_params,  # 只传递有效的参数
                 )
-                async for resp in executor:
+
+                _final_resp: CallToolResult | None = None
+                async for resp in executor:  # type: ignore
                     if isinstance(resp, CallToolResult):
                         res = resp
+                        _final_resp = resp
                         if isinstance(res.content[0], TextContent):
                             tool_call_result_blocks.append(
                                 ToolCallMessageSegment(
                                     role="tool",
                                     tool_call_id=func_tool_id,
                                     content=res.content[0].text,
-                                )
+                                ),
                             )
                             yield MessageChain().message(res.content[0].text)
                         elif isinstance(res.content[0], ImageContent):
@@ -228,10 +272,10 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                                     role="tool",
                                     tool_call_id=func_tool_id,
                                     content="返回了图片(已直接发送给用户)",
-                                )
+                                ),
                             )
                             yield MessageChain(type="tool_direct_result").base64_image(
-                                res.content[0].data
+                                res.content[0].data,
                             )
                         elif isinstance(res.content[0], EmbeddedResource):
                             resource = res.content[0].resource
@@ -241,7 +285,7 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                                         role="tool",
                                         tool_call_id=func_tool_id,
                                         content=resource.text,
-                                    )
+                                    ),
                                 )
                                 yield MessageChain().message(resource.text)
                             elif (
@@ -254,10 +298,10 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                                         role="tool",
                                         tool_call_id=func_tool_id,
                                         content="返回了图片(已直接发送给用户)",
-                                    )
+                                    ),
                                 )
                                 yield MessageChain(
-                                    type="tool_direct_result"
+                                    type="tool_direct_result",
                                 ).base64_image(resource.blob)
                             else:
                                 tool_call_result_blocks.append(
@@ -265,40 +309,41 @@ class ToolLoopAgentRunner(BaseAgentRunner[TContext]):
                                         role="tool",
                                         tool_call_id=func_tool_id,
                                         content="返回的数据类型不受支持",
-                                    )
+                                    ),
                                 )
                                 yield MessageChain().message("返回的数据类型不受支持。")
 
                     elif resp is None:
                         # Tool 直接请求发送消息给用户
                         # 这里我们将直接结束 Agent Loop。
-                        self._transition_state(AgentState.DONE)
-                        if res := self.run_context.event.get_result():
-                            if res.chain:
-                                yield MessageChain(
-                                    chain=res.chain, type="tool_direct_result"
-                                )
-                    else:
+                        # 发送消息逻辑在 ToolExecutor 中处理了。
                         logger.warning(
-                            f"Tool 返回了不支持的类型: {type(resp)}，将忽略。"
+                            f"{func_tool_name} 没有没有返回值或者将结果直接发送给用户，此工具调用不会被记录到历史中。"
+                        )
+                        self._transition_state(AgentState.DONE)
+                    else:
+                        # 不应该出现其他类型
+                        logger.warning(
+                            f"Tool 返回了不支持的类型: {type(resp)}，将忽略。",
                         )
 
                 try:
                     await self.agent_hooks.on_tool_end(
-                        self.run_context, func_tool, func_tool_args, None
+                        self.run_context,
+                        func_tool,
+                        func_tool_args,
+                        _final_resp,
                     )
                 except Exception as e:
                     logger.error(f"Error in on_tool_end hook: {e}", exc_info=True)
-
-                self.run_context.event.clear_result()
             except Exception as e:
                 logger.warning(traceback.format_exc())
                 tool_call_result_blocks.append(
                     ToolCallMessageSegment(
                         role="tool",
                         tool_call_id=func_tool_id,
-                        content=f"error: {str(e)}",
-                    )
+                        content=f"error: {e!s}",
+                    ),
                 )
 
         # 处理函数调用响应
