@@ -1,55 +1,75 @@
-from dataclasses import dataclass
+from collections.abc import Awaitable, Callable
+from typing import Any, Generic
+
+import jsonschema
+import mcp
 from deprecated import deprecated
-from typing import Awaitable, Callable, Literal, Any, Optional
-from .mcp_client import MCPClient
+from pydantic import model_validator
+from pydantic.dataclasses import dataclass
+
+from .run_context import ContextWrapper, TContext
+
+ParametersType = dict[str, Any]
 
 
 @dataclass
-class FunctionTool:
-    """A class representing a function tool that can be used in function calling."""
+class ToolSchema:
+    """A class representing the schema of a tool for function calling."""
 
     name: str
-    parameters: dict | None = None
-    description: str | None = None
-    handler: Callable[..., Awaitable[Any]] | None = None
-    """处理函数, 当 origin 为 mcp 时，这个为空"""
-    handler_module_path: str | None = None
-    """处理函数的模块路径，当 origin 为 mcp 时，这个为空
+    """The name of the tool."""
 
-    必须要保留这个字段, handler 在初始化会被 functools.partial 包装，导致 handler 的 __module__ 为 functools
+    description: str
+    """The description of the tool."""
+
+    parameters: ParametersType
+    """The parameters of the tool, in JSON Schema format."""
+
+    @model_validator(mode="after")
+    def validate_parameters(self) -> "ToolSchema":
+        jsonschema.validate(
+            self.parameters, jsonschema.Draft202012Validator.META_SCHEMA
+        )
+        return self
+
+
+@dataclass
+class FunctionTool(ToolSchema, Generic[TContext]):
+    """A callable tool, for function calling."""
+
+    handler: Callable[..., Awaitable[Any]] | None = None
+    """a callable that implements the tool's functionality. It should be an async function."""
+
+    handler_module_path: str | None = None
+    """
+    The module path of the handler function. This is empty when the origin is mcp.
+    This field must be retained, as the handler will be wrapped in functools.partial during initialization,
+    causing the handler's __module__ to be functools
     """
     active: bool = True
-    """是否激活"""
-
-    origin: Literal["local", "mcp"] = "local"
-    """函数工具的来源, local 为本地函数工具, mcp 为 MCP 服务"""
-
-    # MCP 相关字段
-    mcp_server_name: str | None = None
-    """MCP 服务名称，当 origin 为 mcp 时有效"""
-    mcp_client: MCPClient | None = None
-    """MCP 客户端，当 origin 为 mcp 时有效"""
+    """
+    Whether the tool is active. This field is a special field for AstrBot.
+    You can ignore it when integrating with other frameworks.
+    """
 
     def __repr__(self):
-        return f"FuncTool(name={self.name}, parameters={self.parameters}, description={self.description}, active={self.active}, origin={self.origin})"
+        return f"FuncTool(name={self.name}, parameters={self.parameters}, description={self.description})"
 
-    def __dict__(self) -> dict[str, Any]:
-        """将 FunctionTool 转换为字典格式"""
-        return {
-            "name": self.name,
-            "parameters": self.parameters,
-            "description": self.description,
-            "active": self.active,
-            "origin": self.origin,
-            "mcp_server_name": self.mcp_server_name,
-        }
+    async def call(
+        self, context: ContextWrapper[TContext], **kwargs
+    ) -> str | mcp.types.CallToolResult:
+        """Run the tool with the given arguments. The handler field has priority."""
+        raise NotImplementedError(
+            "FunctionTool.call() must be implemented by subclasses or set a handler."
+        )
 
 
 class ToolSet:
     """A set of function tools that can be used in function calling.
 
     This class provides methods to add, remove, and retrieve tools, as well as
-    convert the tools to different API formats (OpenAI, Anthropic, Google GenAI)."""
+    convert the tools to different API formats (OpenAI, Anthropic, Google GenAI).
+    """
 
     def __init__(self, tools: list[FunctionTool] | None = None):
         self.tools: list[FunctionTool] = tools or []
@@ -71,7 +91,7 @@ class ToolSet:
         """Remove a tool by its name."""
         self.tools = [tool for tool in self.tools if tool.name != name]
 
-    def get_tool(self, name: str) -> Optional[FunctionTool]:
+    def get_tool(self, name: str) -> FunctionTool | None:
         """Get a tool by its name."""
         for tool in self.tools:
             if tool.name == name:
@@ -132,10 +152,8 @@ class ToolSet:
             }
 
             if (
-                tool.parameters
-                and tool.parameters.get("properties")
-                or not omit_empty_parameter_field
-            ):
+                tool.parameters and tool.parameters.get("properties")
+            ) or not omit_empty_parameter_field:
                 func_def["function"]["parameters"] = tool.parameters
 
             result.append(func_def)
@@ -185,7 +203,8 @@ class ToolSet:
             if "type" in schema and schema["type"] in supported_types:
                 result["type"] = schema["type"]
                 if "format" in schema and schema["format"] in supported_formats.get(
-                    result["type"], set()
+                    result["type"],
+                    set(),
                 ):
                     result["format"] = schema["format"]
             else:
@@ -222,7 +241,7 @@ class ToolSet:
 
         tools = []
         for tool in self.tools:
-            d = {
+            d: dict[str, Any] = {
                 "name": tool.name,
                 "description": tool.description,
             }
