@@ -1,24 +1,27 @@
 import asyncio
-import typing as T
 import threading
+import typing as T
 from datetime import datetime, timedelta
+
+from sqlalchemy.ext.asyncio import AsyncSession
+from sqlmodel import col, delete, desc, func, or_, select, text, update
+
 from astrbot.core.db import BaseDatabase
 from astrbot.core.db.po import (
-    ConversationV2,
-    PlatformStat,
-    PlatformMessageHistory,
     Attachment,
+    ConversationV2,
     Persona,
+    PlatformMessageHistory,
+    PlatformStat,
     Preference,
-    Stats as DeprecatedStats,
-    Platform as DeprecatedPlatformStat,
     SQLModel,
 )
-
-from sqlalchemy import select, update, delete, text
-from sqlalchemy.ext.asyncio import AsyncSession
-from sqlalchemy.sql import func
-from sqlalchemy import or_
+from astrbot.core.db.po import (
+    Platform as DeprecatedPlatformStat,
+)
+from astrbot.core.db.po import (
+    Stats as DeprecatedStats,
+)
 
 NOT_GIVEN = T.TypeVar("NOT_GIVEN")
 
@@ -34,6 +37,12 @@ class SQLiteDatabase(BaseDatabase):
         """Initialize the database by creating tables if they do not exist."""
         async with self.engine.begin() as conn:
             await conn.run_sync(SQLModel.metadata.create_all)
+            await conn.execute(text("PRAGMA journal_mode=WAL"))
+            await conn.execute(text("PRAGMA synchronous=NORMAL"))
+            await conn.execute(text("PRAGMA cache_size=20000"))
+            await conn.execute(text("PRAGMA temp_store=MEMORY"))
+            await conn.execute(text("PRAGMA mmap_size=134217728"))
+            await conn.execute(text("PRAGMA optimize"))
             await conn.commit()
 
     # ====
@@ -42,10 +51,10 @@ class SQLiteDatabase(BaseDatabase):
 
     async def insert_platform_stats(
         self,
-        platform_id: str,
-        platform_type: str,
-        count: int = 1,
-        timestamp: datetime = None,
+        platform_id,
+        platform_type,
+        count=1,
+        timestamp=None,
     ) -> None:
         """Insert a new platform statistic record."""
         async with self.get_db() as session:
@@ -53,7 +62,9 @@ class SQLiteDatabase(BaseDatabase):
             async with session.begin():
                 if timestamp is None:
                     timestamp = datetime.now().replace(
-                        minute=0, second=0, microsecond=0
+                        minute=0,
+                        second=0,
+                        microsecond=0,
                     )
                 current_hour = timestamp
                 await session.execute(
@@ -76,12 +87,14 @@ class SQLiteDatabase(BaseDatabase):
         async with self.get_db() as session:
             session: AsyncSession
             result = await session.execute(
-                select(func.count(PlatformStat.platform_id)).select_from(PlatformStat)
+                select(func.count(col(PlatformStat.platform_id))).select_from(
+                    PlatformStat,
+                ),
             )
             count = result.scalar_one_or_none()
             return count if count is not None else 0
 
-    async def get_platform_stats(self, offset_sec: int = 86400) -> T.List[PlatformStat]:
+    async def get_platform_stats(self, offset_sec: int = 86400) -> list[PlatformStat]:
         """Get platform statistics within the specified offset in seconds and group by platform_id."""
         async with self.get_db() as session:
             session: AsyncSession
@@ -96,7 +109,7 @@ class SQLiteDatabase(BaseDatabase):
                 """),
                 {"start_time": start_time},
             )
-            return result.scalars().all()
+            return list(result.scalars().all())
 
     # ====
     # Conversation Management
@@ -112,7 +125,7 @@ class SQLiteDatabase(BaseDatabase):
             if platform_id:
                 query = query.where(ConversationV2.platform_id == platform_id)
             # order by
-            query = query.order_by(ConversationV2.created_at.desc())
+            query = query.order_by(desc(ConversationV2.created_at))
             result = await session.execute(query)
 
             return result.scalars().all()
@@ -130,9 +143,9 @@ class SQLiteDatabase(BaseDatabase):
             offset = (page - 1) * page_size
             result = await session.execute(
                 select(ConversationV2)
-                .order_by(ConversationV2.created_at.desc())
+                .order_by(desc(ConversationV2.created_at))
                 .offset(offset)
-                .limit(page_size)
+                .limit(page_size),
             )
             return result.scalars().all()
 
@@ -151,25 +164,26 @@ class SQLiteDatabase(BaseDatabase):
 
             if platform_ids:
                 base_query = base_query.where(
-                    ConversationV2.platform_id.in_(platform_ids)
+                    col(ConversationV2.platform_id).in_(platform_ids),
                 )
             if search_query:
                 search_query = search_query.encode("unicode_escape").decode("utf-8")
                 base_query = base_query.where(
                     or_(
-                        ConversationV2.title.ilike(f"%{search_query}%"),
-                        ConversationV2.content.ilike(f"%{search_query}%"),
-                        ConversationV2.user_id.ilike(f"%{search_query}%"),
-                    )
+                        col(ConversationV2.title).ilike(f"%{search_query}%"),
+                        col(ConversationV2.content).ilike(f"%{search_query}%"),
+                        col(ConversationV2.user_id).ilike(f"%{search_query}%"),
+                        col(ConversationV2.conversation_id).ilike(f"%{search_query}%"),
+                    ),
                 )
             if "message_types" in kwargs and len(kwargs["message_types"]) > 0:
                 for msg_type in kwargs["message_types"]:
                     base_query = base_query.where(
-                        ConversationV2.user_id.ilike(f"%:{msg_type}:%")
+                        col(ConversationV2.user_id).ilike(f"%:{msg_type}:%"),
                     )
             if "platforms" in kwargs and len(kwargs["platforms"]) > 0:
                 base_query = base_query.where(
-                    ConversationV2.platform_id.in_(kwargs["platforms"])
+                    col(ConversationV2.platform_id).in_(kwargs["platforms"]),
                 )
 
             # Get total count matching the filters
@@ -180,7 +194,7 @@ class SQLiteDatabase(BaseDatabase):
             # Get paginated results
             offset = (page - 1) * page_size
             result_query = (
-                base_query.order_by(ConversationV2.created_at.desc())
+                base_query.order_by(desc(ConversationV2.created_at))
                 .offset(offset)
                 .limit(page_size)
             )
@@ -226,7 +240,7 @@ class SQLiteDatabase(BaseDatabase):
             session: AsyncSession
             async with session.begin():
                 query = update(ConversationV2).where(
-                    ConversationV2.conversation_id == cid
+                    col(ConversationV2.conversation_id) == cid,
                 )
                 values = {}
                 if title is not None:
@@ -236,7 +250,7 @@ class SQLiteDatabase(BaseDatabase):
                 if content is not None:
                     values["content"] = content
                 if not values:
-                    return
+                    return None
                 query = query.values(**values)
                 await session.execute(query)
         return await self.get_conversation_by_id(cid)
@@ -246,9 +260,130 @@ class SQLiteDatabase(BaseDatabase):
             session: AsyncSession
             async with session.begin():
                 await session.execute(
-                    delete(ConversationV2).where(ConversationV2.conversation_id == cid)
+                    delete(ConversationV2).where(
+                        col(ConversationV2.conversation_id) == cid,
+                    ),
                 )
 
+    async def delete_conversations_by_user_id(self, user_id: str) -> None:
+        async with self.get_db() as session:
+            session: AsyncSession
+            async with session.begin():
+                await session.execute(
+                    delete(ConversationV2).where(
+                        col(ConversationV2.user_id) == user_id
+                    ),
+                )
+
+    async def get_session_conversations(
+        self,
+        page=1,
+        page_size=20,
+        search_query=None,
+        platform=None,
+    ) -> tuple[list[dict], int]:
+        """Get paginated session conversations with joined conversation and persona details."""
+        async with self.get_db() as session:
+            session: AsyncSession
+            offset = (page - 1) * page_size
+
+            base_query = (
+                select(
+                    col(Preference.scope_id).label("session_id"),
+                    func.json_extract(Preference.value, "$.val").label(
+                        "conversation_id",
+                    ),  # type: ignore
+                    col(ConversationV2.persona_id).label("persona_id"),
+                    col(ConversationV2.title).label("title"),
+                    col(Persona.persona_id).label("persona_name"),
+                )
+                .select_from(Preference)
+                .outerjoin(
+                    ConversationV2,
+                    func.json_extract(Preference.value, "$.val")
+                    == ConversationV2.conversation_id,
+                )
+                .outerjoin(
+                    Persona,
+                    col(ConversationV2.persona_id) == Persona.persona_id,
+                )
+                .where(Preference.scope == "umo", Preference.key == "sel_conv_id")
+            )
+
+            # 搜索筛选
+            if search_query:
+                search_pattern = f"%{search_query}%"
+                base_query = base_query.where(
+                    or_(
+                        col(Preference.scope_id).ilike(search_pattern),
+                        col(ConversationV2.title).ilike(search_pattern),
+                        col(Persona.persona_id).ilike(search_pattern),
+                    ),
+                )
+
+            # 平台筛选
+            if platform:
+                platform_pattern = f"{platform}:%"
+                base_query = base_query.where(
+                    col(Preference.scope_id).like(platform_pattern),
+                )
+
+            # 排序
+            base_query = base_query.order_by(Preference.scope_id)
+
+            # 分页结果
+            result_query = base_query.offset(offset).limit(page_size)
+            result = await session.execute(result_query)
+            rows = result.fetchall()
+
+            # 查询总数（应用相同的筛选条件）
+            count_base_query = (
+                select(func.count(col(Preference.scope_id)))
+                .select_from(Preference)
+                .outerjoin(
+                    ConversationV2,
+                    func.json_extract(Preference.value, "$.val")
+                    == ConversationV2.conversation_id,
+                )
+                .outerjoin(
+                    Persona,
+                    col(ConversationV2.persona_id) == Persona.persona_id,
+                )
+                .where(Preference.scope == "umo", Preference.key == "sel_conv_id")
+            )
+
+            # 应用相同的搜索和平台筛选条件到计数查询
+            if search_query:
+                search_pattern = f"%{search_query}%"
+                count_base_query = count_base_query.where(
+                    or_(
+                        col(Preference.scope_id).ilike(search_pattern),
+                        col(ConversationV2.title).ilike(search_pattern),
+                        col(Persona.persona_id).ilike(search_pattern),
+                    ),
+                )
+
+            if platform:
+                platform_pattern = f"{platform}:%"
+                count_base_query = count_base_query.where(
+                    col(Preference.scope_id).like(platform_pattern),
+                )
+
+            total_result = await session.execute(count_base_query)
+            total = total_result.scalar() or 0
+
+            sessions_data = [
+                {
+                    "session_id": row.session_id,
+                    "conversation_id": row.conversation_id,
+                    "persona_id": row.persona_id,
+                    "title": row.title,
+                    "persona_name": row.persona_name,
+                }
+                for row in rows
+            ]
+            return sessions_data, total
+
     async def insert_platform_message_history(
         self,
         platform_id,
@@ -272,7 +407,10 @@ class SQLiteDatabase(BaseDatabase):
                 return new_history
 
     async def delete_platform_message_offset(
-        self, platform_id, user_id, offset_sec=86400
+        self,
+        platform_id,
+        user_id,
+        offset_sec=86400,
     ):
         """Delete platform message history records older than the specified offset."""
         async with self.get_db() as session:
@@ -282,14 +420,18 @@ class SQLiteDatabase(BaseDatabase):
                 cutoff_time = now - timedelta(seconds=offset_sec)
                 await session.execute(
                     delete(PlatformMessageHistory).where(
-                        PlatformMessageHistory.platform_id == platform_id,
-                        PlatformMessageHistory.user_id == user_id,
-                        PlatformMessageHistory.created_at < cutoff_time,
-                    )
+                        col(PlatformMessageHistory.platform_id) == platform_id,
+                        col(PlatformMessageHistory.user_id) == user_id,
+                        col(PlatformMessageHistory.created_at) < cutoff_time,
+                    ),
                 )
 
     async def get_platform_message_history(
-        self, platform_id, user_id, page=1, page_size=20
+        self,
+        platform_id,
+        user_id,
+        page=1,
+        page_size=20,
     ):
         """Get platform message history records."""
         async with self.get_db() as session:
@@ -301,7 +443,7 @@ class SQLiteDatabase(BaseDatabase):
                     PlatformMessageHistory.platform_id == platform_id,
                     PlatformMessageHistory.user_id == user_id,
                 )
-                .order_by(PlatformMessageHistory.created_at.desc())
+                .order_by(desc(PlatformMessageHistory.created_at))
             )
             result = await session.execute(query.offset(offset).limit(page_size))
             return result.scalars().all()
@@ -323,12 +465,16 @@ class SQLiteDatabase(BaseDatabase):
         """Get an attachment by its ID."""
         async with self.get_db() as session:
             session: AsyncSession
-            query = select(Attachment).where(Attachment.id == attachment_id)
+            query = select(Attachment).where(Attachment.attachment_id == attachment_id)
             result = await session.execute(query)
             return result.scalar_one_or_none()
 
     async def insert_persona(
-        self, persona_id, system_prompt, begin_dialogs=None, tools=None
+        self,
+        persona_id,
+        system_prompt,
+        begin_dialogs=None,
+        tools=None,
     ):
         """Insert a new persona record."""
         async with self.get_db() as session:
@@ -360,13 +506,17 @@ class SQLiteDatabase(BaseDatabase):
             return result.scalars().all()
 
     async def update_persona(
-        self, persona_id, system_prompt=None, begin_dialogs=None, tools=NOT_GIVEN
+        self,
+        persona_id,
+        system_prompt=None,
+        begin_dialogs=None,
+        tools=NOT_GIVEN,
     ):
         """Update a persona's system prompt or begin dialogs."""
         async with self.get_db() as session:
             session: AsyncSession
             async with session.begin():
-                query = update(Persona).where(Persona.persona_id == persona_id)
+                query = update(Persona).where(col(Persona.persona_id) == persona_id)
                 values = {}
                 if system_prompt is not None:
                     values["system_prompt"] = system_prompt
@@ -375,7 +525,7 @@ class SQLiteDatabase(BaseDatabase):
                 if tools is not NOT_GIVEN:
                     values["tools"] = tools
                 if not values:
-                    return
+                    return None
                 query = query.values(**values)
                 await session.execute(query)
         return await self.get_persona_by_id(persona_id)
@@ -386,7 +536,7 @@ class SQLiteDatabase(BaseDatabase):
             session: AsyncSession
             async with session.begin():
                 await session.execute(
-                    delete(Persona).where(Persona.persona_id == persona_id)
+                    delete(Persona).where(col(Persona.persona_id) == persona_id),
                 )
 
     async def insert_preference_or_update(self, scope, scope_id, key, value):
@@ -405,7 +555,10 @@ class SQLiteDatabase(BaseDatabase):
                     existing_preference.value = value
                 else:
                     new_preference = Preference(
-                        scope=scope, scope_id=scope_id, key=key, value=value
+                        scope=scope,
+                        scope_id=scope_id,
+                        key=key,
+                        value=value,
                     )
                     session.add(new_preference)
                 return existing_preference or new_preference
@@ -441,10 +594,10 @@ class SQLiteDatabase(BaseDatabase):
             async with session.begin():
                 await session.execute(
                     delete(Preference).where(
-                        Preference.scope == scope,
-                        Preference.scope_id == scope_id,
-                        Preference.key == key,
-                    )
+                        col(Preference.scope) == scope,
+                        col(Preference.scope_id) == scope_id,
+                        col(Preference.key) == key,
+                    ),
                 )
             await session.commit()
 
@@ -455,8 +608,9 @@ class SQLiteDatabase(BaseDatabase):
             async with session.begin():
                 await session.execute(
                     delete(Preference).where(
-                        Preference.scope == scope, Preference.scope_id == scope_id
-                    )
+                        col(Preference.scope) == scope,
+                        col(Preference.scope_id) == scope_id,
+                    ),
                 )
             await session.commit()
 
@@ -473,7 +627,7 @@ class SQLiteDatabase(BaseDatabase):
                 now = datetime.now()
                 start_time = now - timedelta(seconds=offset_sec)
                 result = await session.execute(
-                    select(PlatformStat).where(PlatformStat.timestamp >= start_time)
+                    select(PlatformStat).where(PlatformStat.timestamp >= start_time),
                 )
                 all_datas = result.scalars().all()
                 deprecated_stats = DeprecatedStats()
@@ -482,8 +636,8 @@ class SQLiteDatabase(BaseDatabase):
                         DeprecatedPlatformStat(
                             name=data.platform_id,
                             count=data.count,
-                            timestamp=data.timestamp.timestamp(),
-                        )
+                            timestamp=int(data.timestamp.timestamp()),
+                        ),
                     )
                 return deprecated_stats
 
@@ -505,7 +659,7 @@ class SQLiteDatabase(BaseDatabase):
             async with self.get_db() as session:
                 session: AsyncSession
                 result = await session.execute(
-                    select(func.sum(PlatformStat.count)).select_from(PlatformStat)
+                    select(func.sum(PlatformStat.count)).select_from(PlatformStat),
                 )
                 total_count = result.scalar_one_or_none()
                 return total_count if total_count is not None else 0
@@ -531,7 +685,7 @@ class SQLiteDatabase(BaseDatabase):
                 result = await session.execute(
                     select(PlatformStat.platform_id, func.sum(PlatformStat.count))
                     .where(PlatformStat.timestamp >= start_time)
-                    .group_by(PlatformStat.platform_id)
+                    .group_by(PlatformStat.platform_id),
                 )
                 grouped_stats = result.all()
                 deprecated_stats = DeprecatedStats()
@@ -540,8 +694,8 @@ class SQLiteDatabase(BaseDatabase):
                         DeprecatedPlatformStat(
                             name=platform_id,
                             count=count,
-                            timestamp=start_time.timestamp(),
-                        )
+                            timestamp=int(start_time.timestamp()),
+                        ),
                     )
                 return deprecated_stats
 
