@@ -1,5 +1,4 @@
-"""
-日志系统, 用于支持核心组件和插件的日志记录, 提供了日志订阅功能
+"""日志系统, 用于支持核心组件和插件的日志记录, 提供了日志订阅功能
 
 const:
     CACHED_SIZE: 日志缓存大小, 用于限制缓存的日志数量
@@ -21,14 +20,14 @@ function:
 4. 订阅者可以使用 register() 方法注册到 LogBroker, 订阅日志流
 """
 
-import logging
-import colorlog
 import asyncio
+import logging
 import os
 import sys
-from collections import deque
 from asyncio import Queue
-from typing import List
+from collections import deque
+
+import colorlog
 
 # 日志缓存大小
 CACHED_SIZE = 200
@@ -52,6 +51,7 @@ def is_plugin_path(pathname):
 
     Returns:
         bool: 如果路径来自插件目录，则返回 True，否则返回 False
+
     """
     if not pathname:
         return False
@@ -68,6 +68,7 @@ def get_short_level_name(level_name):
 
     Returns:
         str: 四个字母的日志级别缩写
+
     """
     level_map = {
         "DEBUG": "DBUG",
@@ -87,13 +88,14 @@ class LogBroker:
 
     def __init__(self):
         self.log_cache = deque(maxlen=CACHED_SIZE)  # 环形缓冲区, 保存最近的日志
-        self.subscribers: List[Queue] = []  # 订阅者列表
+        self.subscribers: list[Queue] = []  # 订阅者列表
 
     def register(self) -> Queue:
         """注册新的订阅者, 并给每个订阅者返回一个带有日志缓存的队列
 
         Returns:
             Queue: 订阅者的队列, 可用于接收日志消息
+
         """
         q = Queue(maxsize=CACHED_SIZE + 10)
         self.subscribers.append(q)
@@ -104,6 +106,7 @@ class LogBroker:
 
         Args:
             q (Queue): 需要取消订阅的队列
+
         """
         self.subscribers.remove(q)
 
@@ -113,6 +116,7 @@ class LogBroker:
         Args:
             log_entry (dict): 日志消息, 包含日志级别和日志内容.
                 example: {"level": "INFO", "data": "This is a log message.", "time": "2023-10-01 12:00:00"}
+
         """
         self.log_cache.append(log_entry)
         for q in self.subscribers:
@@ -138,6 +142,7 @@ class LogQueueHandler(logging.Handler):
 
         Args:
             record (logging.LogRecord): 日志记录对象, 包含日志信息
+
         """
         log_entry = self.format(record)
         self.log_broker.publish(
@@ -145,7 +150,7 @@ class LogQueueHandler(logging.Handler):
                 "level": record.levelname,
                 "time": record.asctime,
                 "data": log_entry,
-            }
+            },
         )
 
 
@@ -164,6 +169,7 @@ class LogManager:
 
         Returns:
             logging.Logger: 返回配置好的日志记录器
+
         """
         logger = logging.getLogger(log_name)
         # 检查该logger或父级logger是否已经有处理器, 如果已经有处理器, 直接返回该logger, 避免重复配置
@@ -171,10 +177,10 @@ class LogManager:
             return logger
         # 如果logger没有处理器
         console_handler = logging.StreamHandler(
-            sys.stdout
+            sys.stdout,
         )  # 创建一个StreamHandler用于控制台输出
         console_handler.setLevel(
-            logging.DEBUG
+            logging.DEBUG,
         )  # 将日志级别设置为DEBUG(最低级别, 显示所有日志), *如果插件没有设置级别, 默认为DEBUG
 
         # 创建彩色日志格式化器, 输出日志格式为: [时间] [插件标签] [日志级别] [文件名:行号]: 日志消息
@@ -195,7 +201,8 @@ class LogManager:
 
         class FileNameFilter(logging.Filter):
             """文件名过滤器类, 用于修改日志记录的文件名格式
-            例如: 将文件路径 /path/to/file.py 转换为 file.<file> 格式"""
+            例如: 将文件路径 /path/to/file.py 转换为 file.<file> 格式
+            """
 
             # 获取这个文件和父文件夹的名字：<folder>.<file> 并且去除 .py
             def filter(self, record):
@@ -231,6 +238,7 @@ class LogManager:
         Args:
             logger (logging.Logger): 日志记录器
             log_broker (LogBroker): 日志代理类, 用于缓存和分发日志消息
+
         """
         handler = LogQueueHandler(log_broker)
         handler.setLevel(logging.DEBUG)
@@ -240,7 +248,7 @@ class LogManager:
             # 为队列处理器设置相同格式的formatter
             handler.setFormatter(
                 logging.Formatter(
-                    "[%(asctime)s] [%(short_levelname)s] %(plugin_tag)s[%(filename)s:%(lineno)d]: %(message)s"
-                )
+                    "[%(asctime)s] [%(short_levelname)s] %(plugin_tag)s[%(filename)s:%(lineno)d]: %(message)s",
+                ),
             )
         logger.addHandler(handler)
