@@ -1,9 +1,11 @@
-from typing import Union, AsyncGenerator
-from ..stage import Stage, register_stage
-from ..context import PipelineContext
-from astrbot.core.platform.astr_message_event import AstrMessageEvent
-from astrbot.core.message.message_event_result import MessageEventResult
+from collections.abc import AsyncGenerator
+
 from astrbot.core import logger
+from astrbot.core.message.message_event_result import MessageEventResult
+from astrbot.core.platform.astr_message_event import AstrMessageEvent
+
+from ..context import PipelineContext
+from ..stage import Stage, register_stage
 from .strategies.strategy import StrategySelector
 
 
@@ -19,8 +21,10 @@ class ContentSafetyCheckStage(Stage):
         self.strategy_selector = StrategySelector(config)
 
     async def process(
-        self, event: AstrMessageEvent, check_text: str | None = None
-    ) -> Union[None, AsyncGenerator[None, None]]:
+        self,
+        event: AstrMessageEvent,
+        check_text: str | None = None,
+    ) -> None | AsyncGenerator[None, None]:
         """检查内容安全"""
         text = check_text if check_text else event.get_message_str()
         ok, info = self.strategy_selector.check(text)
@@ -28,8 +32,8 @@ class ContentSafetyCheckStage(Stage):
             if event.is_at_or_wake_command:
                 event.set_result(
                     MessageEventResult().message(
-                        "你的消息或者大模型的响应中包含不适当的内容，已被屏蔽。"
-                    )
+                        "你的消息或者大模型的响应中包含不适当的内容，已被屏蔽。",
+                    ),
                 )
                 yield
             event.stop_event()
