@@ -1,16 +1,16 @@
-from . import ContentSafetyStrategy
-from typing import List, Tuple
 from astrbot import logger
 
+from . import ContentSafetyStrategy
+
 
 class StrategySelector:
     def __init__(self, config: dict) -> None:
-        self.enabled_strategies: List[ContentSafetyStrategy] = []
+        self.enabled_strategies: list[ContentSafetyStrategy] = []
         if config["internal_keywords"]["enable"]:
             from .keywords import KeywordsStrategy
 
             self.enabled_strategies.append(
-                KeywordsStrategy(config["internal_keywords"]["extra_keywords"])
+                KeywordsStrategy(config["internal_keywords"]["extra_keywords"]),
             )
         if config["baidu_aip"]["enable"]:
             try:
@@ -23,10 +23,10 @@ class StrategySelector:
                     config["baidu_aip"]["app_id"],
                     config["baidu_aip"]["api_key"],
                     config["baidu_aip"]["secret_key"],
-                )
+                ),
             )
 
-    def check(self, content: str) -> Tuple[bool, str]:
+    def check(self, content: str) -> tuple[bool, str]:
         for strategy in self.enabled_strategies:
             ok, info = strategy.check(content)
             if not ok:
