@@ -1,5 +1,4 @@
-"""
-The MIT License (MIT)
+"""The MIT License (MIT)
 
 Copyright (c) 2014-2020 messense
 
@@ -23,13 +22,11 @@ SOFTWARE.
 """
 
 from optionaldict import optionaldict
-
 from wechatpy.client.api.base import BaseWeChatAPI
 
 
 class WeChatKFMessage(BaseWeChatAPI):
-    """
-    发送微信客服消息
+    """发送微信客服消息
 
     https://work.weixin.qq.com/api/doc/90000/90135/94677
 
@@ -46,8 +43,7 @@ class WeChatKFMessage(BaseWeChatAPI):
     """
 
     def send(self, user_id, open_kfid, msgid="", msg=None):
-        """
-        当微信客户处于“新接入待处理”或“由智能助手接待”状态下，可调用该接口给用户发送消息。
+        """当微信客户处于“新接入待处理”或“由智能助手接待”状态下，可调用该接口给用户发送消息。
         注意仅当微信客户在主动发送消息给客服后的48小时内，企业可发送消息给客户，最多可发送5条消息；若用户继续发送消息，企业可再次下发消息。
         支持发送消息类型：文本、图片、语音、视频、文件、图文、小程序、菜单消息、地理位置。
 
@@ -127,7 +123,13 @@ class WeChatKFMessage(BaseWeChatAPI):
         )
 
     def send_msgmenu(
-        self, user_id, open_kfid, head_content, menu_list, tail_content, msgid=""
+        self,
+        user_id,
+        open_kfid,
+        head_content,
+        menu_list,
+        tail_content,
+        msgid="",
     ):
         return self.send(
             user_id,
@@ -144,7 +146,14 @@ class WeChatKFMessage(BaseWeChatAPI):
         )
 
     def send_location(
-        self, user_id, open_kfid, name, address, latitude, longitude, msgid=""
+        self,
+        user_id,
+        open_kfid,
+        name,
+        address,
+        latitude,
+        longitude,
+        msgid="",
     ):
         return self.send(
             user_id,
@@ -162,7 +171,14 @@ class WeChatKFMessage(BaseWeChatAPI):
         )
 
     def send_miniprogram(
-        self, user_id, open_kfid, appid, title, thumb_media_id, pagepath, msgid=""
+        self,
+        user_id,
+        open_kfid,
+        appid,
+        title,
+        thumb_media_id,
+        pagepath,
+        msgid="",
     ):
         return self.send(
             user_id,
