@@ -1,16 +1,18 @@
 import abc
-from typing import List
-from typing import AsyncGenerator
+import asyncio
+from collections.abc import AsyncGenerator
+from dataclasses import dataclass
+
+from astrbot.core.agent.message import Message
 from astrbot.core.agent.tool import ToolSet
+from astrbot.core.db.po import Personality
 from astrbot.core.provider.entities import (
     LLMResponse,
-    ToolCallsResult,
     ProviderType,
     RerankResult,
+    ToolCallsResult,
 )
 from astrbot.core.provider.register import provider_cls_map
-from astrbot.core.db.po import Personality
-from dataclasses import dataclass
 
 
 @dataclass
@@ -22,24 +24,28 @@ class ProviderMeta:
 
 
 class AbstractProvider(abc.ABC):
+    """Provider Abstract Class"""
+
     def __init__(self, provider_config: dict) -> None:
         super().__init__()
         self.model_name = ""
         self.provider_config = provider_config
 
     def set_model(self, model_name: str):
-        """设置当前使用的模型名称"""
+        """Set the current model name"""
         self.model_name = model_name
 
     def get_model(self) -> str:
-        """获得当前使用的模型名称"""
+        """Get the current model name"""
         return self.model_name
 
     def meta(self) -> ProviderMeta:
-        """获取 Provider 的元数据"""
+        """Get the provider metadata"""
         provider_type_name = self.provider_config["type"]
         meta_data = provider_cls_map.get(provider_type_name)
         provider_type = meta_data.provider_type if meta_data else None
+        if provider_type is None:
+            raise ValueError(f"Cannot find provider type: {provider_type_name}")
         return ProviderMeta(
             id=self.provider_config["id"],
             model=self.get_model(),
@@ -49,6 +55,8 @@ class AbstractProvider(abc.ABC):
 
 
 class Provider(AbstractProvider):
+    """Chat Provider"""
+
     def __init__(
         self,
         provider_config: dict,
@@ -64,98 +72,114 @@ class Provider(AbstractProvider):
 
     @abc.abstractmethod
     def get_current_key(self) -> str:
-        raise NotImplementedError()
+        raise NotImplementedError
 
-    def get_keys(self) -> List[str]:
+    def get_keys(self) -> list[str]:
         """获得提供商 Key"""
-        return self.provider_config.get("key", [])
+        keys = self.provider_config.get("key", [""])
+        return keys or [""]
 
     @abc.abstractmethod
     def set_key(self, key: str):
-        raise NotImplementedError()
+        raise NotImplementedError
 
     @abc.abstractmethod
-    def get_models(self) -> List[str]:
+    async def get_models(self) -> list[str]:
         """获得支持的模型列表"""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     @abc.abstractmethod
     async def text_chat(
         self,
-        prompt: str,
-        session_id: str = None,
-        image_urls: list[str] = None,
-        func_tool: ToolSet = None,
-        contexts: list = None,
-        system_prompt: str = None,
-        tool_calls_result: ToolCallsResult | list[ToolCallsResult] = None,
+        prompt: str | None = None,
+        session_id: str | None = None,
+        image_urls: list[str] | None = None,
+        func_tool: ToolSet | None = None,
+        contexts: list[Message] | list[dict] | None = None,
+        system_prompt: str | None = None,
+        tool_calls_result: ToolCallsResult | list[ToolCallsResult] | None = None,
         model: str | None = None,
         **kwargs,
     ) -> LLMResponse:
         """获得 LLM 的文本对话结果。会使用当前的模型进行对话。
 
         Args:
-            prompt: 提示词
+            prompt: 提示词，和 contexts 二选一使用，如果都指定，则会将 prompt（以及可能的 image_urls） 作为最新的一条记录添加到 contexts 中
             session_id: 会话 ID(此属性已经被废弃)
             image_urls: 图片 URL 列表
-            tools: Function-calling 工具
-            contexts: 上下文
+            tools: tool set
+            contexts: 上下文，和 prompt 二选一使用
             tool_calls_result: 回传给 LLM 的工具调用结果。参考: https://platform.openai.com/docs/guides/function-calling
             kwargs: 其他参数
 
         Notes:
             - 如果传入了 image_urls，将会在对话时附上图片。如果模型不支持图片输入，将会抛出错误。
             - 如果传入了 tools，将会使用 tools 进行 Function-calling。如果模型不支持 Function-calling，将会抛出错误。
+
         """
         ...
 
     async def text_chat_stream(
         self,
-        prompt: str,
-        session_id: str = None,
-        image_urls: list[str] = None,
-        func_tool: ToolSet = None,
-        contexts: list = None,
-        system_prompt: str = None,
-        tool_calls_result: ToolCallsResult | list[ToolCallsResult] = None,
+        prompt: str | None = None,
+        session_id: str | None = None,
+        image_urls: list[str] | None = None,
+        func_tool: ToolSet | None = None,
+        contexts: list[Message] | list[dict] | None = None,
+        system_prompt: str | None = None,
+        tool_calls_result: ToolCallsResult | list[ToolCallsResult] | None = None,
         model: str | None = None,
         **kwargs,
     ) -> AsyncGenerator[LLMResponse, None]:
         """获得 LLM 的流式文本对话结果。会使用当前的模型进行对话。在生成的最后会返回一次完整的结果。
 
         Args:
-            prompt: 提示词
+            prompt: 提示词，和 contexts 二选一使用，如果都指定，则会将 prompt（以及可能的 image_urls） 作为最新的一条记录添加到 contexts 中
             session_id: 会话 ID(此属性已经被废弃)
             image_urls: 图片 URL 列表
-            tools: Function-calling 工具
-            contexts: 上下文
+            tools: tool set
+            contexts: 上下文，和 prompt 二选一使用
             tool_calls_result: 回传给 LLM 的工具调用结果。参考: https://platform.openai.com/docs/guides/function-calling
             kwargs: 其他参数
 
         Notes:
             - 如果传入了 image_urls，将会在对话时附上图片。如果模型不支持图片输入，将会抛出错误。
             - 如果传入了 tools，将会使用 tools 进行 Function-calling。如果模型不支持 Function-calling，将会抛出错误。
+
         """
         ...
 
-    async def pop_record(self, context: List):
-        """
-        弹出 context 第一条非系统提示词对话记录
-        """
+    async def pop_record(self, context: list):
+        """弹出 context 第一条非系统提示词对话记录"""
         poped = 0
         indexs_to_pop = []
         for idx, record in enumerate(context):
             if record["role"] == "system":
                 continue
-            else:
-                indexs_to_pop.append(idx)
-                poped += 1
-                if poped == 2:
-                    break
+            indexs_to_pop.append(idx)
+            poped += 1
+            if poped == 2:
+                break
 
         for idx in reversed(indexs_to_pop):
             context.pop(idx)
 
+    def _ensure_message_to_dicts(
+        self,
+        messages: list[dict] | list[Message] | None,
+    ) -> list[dict]:
+        """Convert a list of Message objects to a list of dictionaries."""
+        if not messages:
+            return []
+        dicts: list[dict] = []
+        for message in messages:
+            if isinstance(message, Message):
+                dicts.append(message.model_dump())
+            else:
+                dicts.append(message)
+
+        return dicts
+
 
 class STTProvider(AbstractProvider):
     def __init__(self, provider_config: dict, provider_settings: dict) -> None:
@@ -166,7 +190,7 @@ class STTProvider(AbstractProvider):
     @abc.abstractmethod
     async def get_text(self, audio_url: str) -> str:
         """获取音频的文本"""
-        raise NotImplementedError()
+        raise NotImplementedError
 
 
 class TTSProvider(AbstractProvider):
@@ -178,7 +202,7 @@ class TTSProvider(AbstractProvider):
     @abc.abstractmethod
     async def get_audio(self, text: str) -> str:
         """获取文本的音频，返回音频文件路径"""
-        raise NotImplementedError()
+        raise NotImplementedError
 
 
 class EmbeddingProvider(AbstractProvider):
@@ -202,6 +226,73 @@ class EmbeddingProvider(AbstractProvider):
         """获取向量的维度"""
         ...
 
+    async def get_embeddings_batch(
+        self,
+        texts: list[str],
+        batch_size: int = 16,
+        tasks_limit: int = 3,
+        max_retries: int = 3,
+        progress_callback=None,
+    ) -> list[list[float]]:
+        """批量获取文本的向量，分批处理以节省内存
+
+        Args:
+            texts: 文本列表
+            batch_size: 每批处理的文本数量
+            tasks_limit: 并发任务数量限制
+            max_retries: 失败时的最大重试次数
+            progress_callback: 进度回调函数，接收参数 (current, total)
+
+        Returns:
+            向量列表
+
+        """
+        semaphore = asyncio.Semaphore(tasks_limit)
+        all_embeddings: list[list[float]] = []
+        failed_batches: list[tuple[int, list[str]]] = []
+        completed_count = 0
+        total_count = len(texts)
+
+        async def process_batch(batch_idx: int, batch_texts: list[str]):
+            nonlocal completed_count
+            async with semaphore:
+                for attempt in range(max_retries):
+                    try:
+                        batch_embeddings = await self.get_embeddings(batch_texts)
+                        all_embeddings.extend(batch_embeddings)
+                        completed_count += len(batch_texts)
+                        if progress_callback:
+                            await progress_callback(completed_count, total_count)
+                        return
+                    except Exception as e:
+                        if attempt == max_retries - 1:
+                            # 最后一次重试失败，记录失败的批次
+                            failed_batches.append((batch_idx, batch_texts))
+                            raise Exception(
+                                f"批次 {batch_idx} 处理失败，已重试 {max_retries} 次: {e!s}",
+                            )
+                        # 等待一段时间后重试，使用指数退避
+                        await asyncio.sleep(2**attempt)
+
+        tasks = []
+        for i in range(0, len(texts), batch_size):
+            batch_texts = texts[i : i + batch_size]
+            batch_idx = i // batch_size
+            tasks.append(process_batch(batch_idx, batch_texts))
+
+        # 收集所有任务的结果，包括失败的任务
+        results = await asyncio.gather(*tasks, return_exceptions=True)
+
+        # 检查是否有失败的任务
+        errors = [r for r in results if isinstance(r, Exception)]
+        if errors:
+            error_msg = (
+                f"有 {len(errors)} 个批次处理失败: {'; '.join(str(e) for e in errors)}"
+            )
+            raise Exception(error_msg)
+
+        return all_embeddings
+
 
 class RerankProvider(AbstractProvider):
     def __init__(self, provider_config: dict, provider_settings: dict) -> None:
@@ -211,7 +302,10 @@ class RerankProvider(AbstractProvider):
 
     @abc.abstractmethod
     async def rerank(
-        self, query: str, documents: list[str], top_n: int | None = None
+        self,
+        query: str,
+        documents: list[str],
+        top_n: int | None = None,
     ) -> list[RerankResult]:
         """获取查询和文档的重排序分数"""
         ...
