@@ -1,6 +1,4 @@
-"""
-插件的重载、启停、安装、卸载等操作。
-"""
+"""插件的重载、启停、安装、卸载等操作。"""
 
 import asyncio
 import functools
@@ -15,6 +13,7 @@ from types import ModuleType
 import yaml
 
 from astrbot.core import logger, pip_installer, sp
+from astrbot.core.agent.handoff import FunctionTool, HandoffTool
 from astrbot.core.config.astrbot_config import AstrBotConfig
 from astrbot.core.provider.register import llm_tools
 from astrbot.core.utils.astrbot_path import (
@@ -22,7 +21,6 @@ from astrbot.core.utils.astrbot_path import (
     get_astrbot_plugin_path,
 )
 from astrbot.core.utils.io import remove_dir
-from astrbot.core.agent.handoff import HandoffTool, FunctionTool
 
 from . import StarMetadata
 from .context import Context
@@ -52,11 +50,13 @@ class PluginManager:
         """存储插件配置的路径。data/config"""
         self.reserved_plugin_path = os.path.abspath(
             os.path.join(
-                os.path.dirname(os.path.abspath(__file__)), "../../../packages"
-            )
+                os.path.dirname(os.path.abspath(__file__)),
+                "../../../packages",
+            ),
         )
         """保留插件的路径。在 packages 目录下"""
         self.conf_schema_fname = "_conf_schema.json"
+        self.logo_fname = "logo.png"
         """插件配置 Schema 文件名"""
         self._pm_lock = asyncio.Lock()
         """StarManager操作互斥锁"""
@@ -79,7 +79,7 @@ class PluginManager:
         except asyncio.CancelledError:
             pass
         except Exception as e:
-            logger.error(f"插件热重载监视任务异常: {str(e)}")
+            logger.error(f"插件热重载监视任务异常: {e!s}")
             logger.error(traceback.format_exc())
 
     async def _handle_file_changes(self, changes):
@@ -94,11 +94,13 @@ class PluginManager:
                 continue
             if star.reserved:
                 plugin_dir_path = os.path.join(
-                    self.reserved_plugin_path, star.root_dir_name
+                    self.reserved_plugin_path,
+                    star.root_dir_name,
                 )
             else:
                 plugin_dir_path = os.path.join(
-                    self.plugin_store_path, star.root_dir_name
+                    self.plugin_store_path,
+                    star.root_dir_name,
                 )
             plugins_to_check.append((plugin_dir_path, star.name))
         reloaded_plugins = set()
@@ -142,14 +144,14 @@ class PluginManager:
                     logger.info(f"插件 {d} 未找到 main.py 或者 {d}.py，跳过。")
                     continue
                 if os.path.exists(os.path.join(path, d, "main.py")) or os.path.exists(
-                    os.path.join(path, d, d + ".py")
+                    os.path.join(path, d, d + ".py"),
                 ):
                     modules.append(
                         {
                             "pname": d,
                             "module": module_str,
                             "module_path": os.path.join(path, d, module_str),
-                        }
+                        },
                     )
         return modules
 
@@ -185,7 +187,7 @@ class PluginManager:
                 try:
                     await pip_installer.install(requirements_path=pth)
                 except Exception as e:
-                    logger.error(f"更新插件 {p} 的依赖失败。Code: {str(e)}")
+                    logger.error(f"更新插件 {p} 的依赖失败。Code: {e!s}")
 
     @staticmethod
     def _load_plugin_metadata(plugin_path: str, plugin_obj=None) -> StarMetadata | None:
@@ -200,7 +202,8 @@ class PluginManager:
 
         if os.path.exists(os.path.join(plugin_path, "metadata.yaml")):
             with open(
-                os.path.join(plugin_path, "metadata.yaml"), "r", encoding="utf-8"
+                os.path.join(plugin_path, "metadata.yaml"),
+                encoding="utf-8",
             ) as f:
                 metadata = yaml.safe_load(f)
         elif plugin_obj and hasattr(plugin_obj, "info"):
@@ -218,7 +221,7 @@ class PluginManager:
                 or "author" not in metadata
             ):
                 raise Exception(
-                    "插件元数据信息不完整。name, desc, version, author 是必须的字段。"
+                    "插件元数据信息不完整。name, desc, version, author 是必须的字段。",
                 )
             metadata = StarMetadata(
                 name=metadata["name"],
@@ -226,13 +229,15 @@ class PluginManager:
                 desc=metadata["desc"],
                 version=metadata["version"],
                 repo=metadata["repo"] if "repo" in metadata else None,
+                display_name=metadata.get("display_name", None),
             )
 
         return metadata
 
     @staticmethod
     def _get_plugin_related_modules(
-        plugin_root_dir: str, is_reserved: bool = False
+        plugin_root_dir: str,
+        is_reserved: bool = False,
     ) -> list[str]:
         """获取与指定插件相关的所有已加载模块名
 
@@ -244,6 +249,7 @@ class PluginManager:
 
         Returns:
             list[str]: 与该插件相关的模块名列表
+
         """
         prefix = "packages." if is_reserved else "data.plugins."
         return [
@@ -266,6 +272,7 @@ class PluginManager:
             module_patterns: 要移除的模块名模式列表（例如 ["data.plugins", "packages"]）
             root_dir_name: 插件根目录名，用于移除与该插件相关的所有模块
             is_reserved: 插件是否为保留插件（影响模块路径前缀）
+
         """
         if module_patterns:
             for pattern in module_patterns:
@@ -276,7 +283,8 @@ class PluginManager:
 
         if root_dir_name:
             for module_name in self._get_plugin_related_modules(
-                root_dir_name, is_reserved
+                root_dir_name,
+                is_reserved,
             ):
                 try:
                     del sys.modules[module_name]
@@ -295,6 +303,7 @@ class PluginManager:
             tuple: 返回 load() 方法的结果，包含 (success, error_message)
                 - success (bool): 重载是否成功
                 - error_message (str|None): 错误信息，成功时为 None
+
         """
         async with self._pm_lock:
             specified_module_path = None
@@ -313,7 +322,7 @@ class PluginManager:
                     except Exception as e:
                         logger.warning(traceback.format_exc())
                         logger.warning(
-                            f"插件 {smd.name} 未被正常终止: {str(e)}, 可能会导致该插件运行不正常。"
+                            f"插件 {smd.name} 未被正常终止: {e!s}, 可能会导致该插件运行不正常。",
                         )
                     if smd.name and smd.module_path:
                         await self._unbind_plugin(smd.name, smd.module_path)
@@ -330,7 +339,7 @@ class PluginManager:
                     except Exception as e:
                         logger.warning(traceback.format_exc())
                         logger.warning(
-                            f"插件 {smd.name} 未被正常终止: {str(e)}, 可能会导致该插件运行不正常。"
+                            f"插件 {smd.name} 未被正常终止: {e!s}, 可能会导致该插件运行不正常。",
                         )
                     if smd.name:
                         await self._unbind_plugin(smd.name, specified_module_path)
@@ -351,6 +360,7 @@ class PluginManager:
             tuple: (success, error_message)
                 - success (bool): 是否全部加载成功
                 - error_message (str|None): 错误信息，成功时为 None
+
         """
         inactivated_plugins = await sp.global_get("inactivated_plugins", [])
         inactivated_llm_tools = await sp.global_get("inactivated_llm_tools", [])
@@ -369,7 +379,8 @@ class PluginManager:
                 # module_path = plugin_module['module_path']
                 root_dir_name = plugin_module["pname"]  # 插件的目录名
                 reserved = plugin_module.get(
-                    "reserved", False
+                    "reserved",
+                    False,
                 )  # 是否是保留插件。目前在 packages/ 目录下的都是保留插件。保留插件不可以卸载。
 
                 path = "data.plugins." if not reserved else "packages."
@@ -392,7 +403,7 @@ class PluginManager:
                     module = __import__(path, fromlist=[module_str])
                 except Exception as e:
                     logger.error(traceback.format_exc())
-                    logger.error(f"插件 {root_dir_name} 导入失败。原因：{str(e)}")
+                    logger.error(f"插件 {root_dir_name} 导入失败。原因：{e!s}")
                     continue
 
                 # 检查 _conf_schema.json
@@ -403,17 +414,20 @@ class PluginManager:
                     else os.path.join(self.reserved_plugin_path, root_dir_name)
                 )
                 plugin_schema_path = os.path.join(
-                    plugin_dir_path, self.conf_schema_fname
+                    plugin_dir_path,
+                    self.conf_schema_fname,
                 )
                 if os.path.exists(plugin_schema_path):
                     # 加载插件配置
-                    with open(plugin_schema_path, "r", encoding="utf-8") as f:
+                    with open(plugin_schema_path, encoding="utf-8") as f:
                         plugin_config = AstrBotConfig(
                             config_path=os.path.join(
-                                self.plugin_config_path, f"{root_dir_name}_config.json"
+                                self.plugin_config_path,
+                                f"{root_dir_name}_config.json",
                             ),
                             schema=json.loads(f.read()),
                         )
+                logo_path = os.path.join(plugin_dir_path, self.logo_fname)
 
                 if path in star_map:
                     # 通过 __init__subclass__ 注册插件
@@ -422,7 +436,7 @@ class PluginManager:
                     try:
                         # yaml 文件的元数据优先
                         metadata_yaml = self._load_plugin_metadata(
-                            plugin_path=plugin_dir_path
+                            plugin_path=plugin_dir_path,
                         )
                         if metadata_yaml:
                             metadata.name = metadata_yaml.name
@@ -430,9 +444,10 @@ class PluginManager:
                             metadata.desc = metadata_yaml.desc
                             metadata.version = metadata_yaml.version
                             metadata.repo = metadata_yaml.repo
+                            metadata.display_name = metadata_yaml.display_name
                     except Exception as e:
                         logger.warning(
-                            f"插件 {root_dir_name} 元数据载入失败: {str(e)}。使用默认元数据。"
+                            f"插件 {root_dir_name} 元数据载入失败: {e!s}。使用默认元数据。",
                         )
                     logger.info(metadata)
                     metadata.config = plugin_config
@@ -441,15 +456,16 @@ class PluginManager:
                         if plugin_config and metadata.star_cls_type:
                             try:
                                 metadata.star_cls = metadata.star_cls_type(
-                                    context=self.context, config=plugin_config
+                                    context=self.context,
+                                    config=plugin_config,
                                 )
                             except TypeError as _:
                                 metadata.star_cls = metadata.star_cls_type(
-                                    context=self.context
+                                    context=self.context,
                                 )
                         elif metadata.star_cls_type:
                             metadata.star_cls = metadata.star_cls_type(
-                                context=self.context
+                                context=self.context,
                             )
                     else:
                         logger.info(f"插件 {metadata.name} 已被禁用。")
@@ -465,7 +481,7 @@ class PluginManager:
                     # 绑定 handler
                     related_handlers = (
                         star_handlers_registry.get_handlers_by_module_name(
-                            metadata.module_path
+                            metadata.module_path,
                         )
                     )
                     for handler in related_handlers:
@@ -501,7 +517,7 @@ class PluginManager:
                 else:
                     # v3.4.0 以前的方式注册插件
                     logger.debug(
-                        f"插件 {path} 未通过装饰器注册。尝试通过旧版本方式载入。"
+                        f"插件 {path} 未通过装饰器注册。尝试通过旧版本方式载入。",
                     )
                     classes = self._get_classes(module)
 
@@ -510,19 +526,21 @@ class PluginManager:
                         if plugin_config:
                             try:
                                 obj = getattr(module, classes[0])(
-                                    context=self.context, config=plugin_config
+                                    context=self.context,
+                                    config=plugin_config,
                                 )  # 实例化插件类
                             except TypeError as _:
                                 obj = getattr(module, classes[0])(
-                                    context=self.context
+                                    context=self.context,
                                 )  # 实例化插件类
                         else:
                             obj = getattr(module, classes[0])(
-                                context=self.context
+                                context=self.context,
                             )  # 实例化插件类
 
                     metadata = self._load_plugin_metadata(
-                        plugin_path=plugin_dir_path, plugin_obj=obj
+                        plugin_path=plugin_dir_path,
+                        plugin_obj=obj,
                     )
                     if not metadata:
                         raise Exception(f"无法找到插件 {plugin_dir_path} 的元数据。")
@@ -540,13 +558,15 @@ class PluginManager:
                 if metadata.module_path in inactivated_plugins:
                     metadata.activated = False
 
-                assert metadata.module_path is not None, (
-                    f"插件 {metadata.name} 的模块路径为空。"
-                )
+                # Plugin logo path
+                if os.path.exists(logo_path):
+                    metadata.logo_path = logo_path
+
+                assert metadata.module_path, f"插件 {metadata.name} 模块路径为空"
 
                 full_names = []
                 for handler in star_handlers_registry.get_handlers_by_module_name(
-                    metadata.module_path
+                    metadata.module_path,
                 ):
                     full_names.append(handler.handler_full_name)
 
@@ -556,7 +576,8 @@ class PluginManager:
                         and handler.handler_name in alter_cmd[metadata.name]
                     ):
                         cmd_type = alter_cmd[metadata.name][handler.handler_name].get(
-                            "permission", "member"
+                            "permission",
+                            "member",
                         )
                         found_permission_filter = False
                         for filter_ in handler.event_filters:
@@ -572,12 +593,12 @@ class PluginManager:
                                 PermissionTypeFilter(
                                     PermissionType.ADMIN
                                     if cmd_type == "admin"
-                                    else PermissionType.MEMBER
-                                )
+                                    else PermissionType.MEMBER,
+                                ),
                             )
 
                         logger.debug(
-                            f"插入权限过滤器 {cmd_type} 到 {metadata.name} 的 {handler.handler_name} 方法。"
+                            f"插入权限过滤器 {cmd_type} 到 {metadata.name} 的 {handler.handler_name} 方法。",
                         )
 
                 metadata.star_handler_full_names = full_names
@@ -592,7 +613,7 @@ class PluginManager:
                 for line in errors.split("\n"):
                     logger.error(f"| {line}")
                 logger.error("----------------------------------")
-                fail_rec += f"加载 {root_dir_name} 插件时出现问题，原因 {str(e)}。\n"
+                fail_rec += f"加载 {root_dir_name} 插件时出现问题，原因 {e!s}。\n"
 
         # 清除 pip.main 导致的多余的 logging handlers
         for handler in logging.root.handlers[:]:
@@ -600,9 +621,8 @@ class PluginManager:
 
         if not fail_rec:
             return True, None
-        else:
-            self.failed_plugin_info = fail_rec
-            return False, fail_rec
+        self.failed_plugin_info = fail_rec
+        return False, fail_rec
 
     async def install_plugin(self, repo_url: str, proxy=""):
         """从仓库 URL 安装插件
@@ -618,6 +638,7 @@ class PluginManager:
                 - repo: 插件的仓库 URL
                 - readme: README.md 文件的内容(如果存在)
                 如果找不到插件元数据则返回 None。
+
         """
         async with self._pm_lock:
             plugin_path = await self.updator.install(repo_url, proxy)
@@ -642,11 +663,11 @@ class PluginManager:
 
             if os.path.exists(readme_path):
                 try:
-                    with open(readme_path, "r", encoding="utf-8") as f:
+                    with open(readme_path, encoding="utf-8") as f:
                         readme_content = f.read()
                 except Exception as e:
                     logger.warning(
-                        f"读取插件 {dir_name} 的 README.md 文件失败: {str(e)}"
+                        f"读取插件 {dir_name} 的 README.md 文件失败: {e!s}",
                     )
 
             plugin_info = None
@@ -659,14 +680,22 @@ class PluginManager:
 
             return plugin_info
 
-    async def uninstall_plugin(self, plugin_name: str):
+    async def uninstall_plugin(
+        self,
+        plugin_name: str,
+        delete_config: bool = False,
+        delete_data: bool = False,
+    ):
         """卸载指定的插件。
 
         Args:
             plugin_name (str): 要卸载的插件名称
+            delete_config (bool): 是否删除插件配置文件，默认为 False
+            delete_data (bool): 是否删除插件数据，默认为 False
 
         Raises:
             Exception: 当插件不存在、是保留插件时，或删除插件文件夹失败时抛出异常
+
         """
         async with self._pm_lock:
             plugin = self.context.get_registered_star(plugin_name)
@@ -683,7 +712,7 @@ class PluginManager:
             except Exception as e:
                 logger.warning(traceback.format_exc())
                 logger.warning(
-                    f"插件 {plugin_name} 未被正常终止 {str(e)}, 可能会导致资源泄露等问题。"
+                    f"插件 {plugin_name} 未被正常终止 {e!s}, 可能会导致资源泄露等问题。",
                 )
 
             # 从 star_registry 和 star_map 中删除
@@ -692,19 +721,66 @@ class PluginManager:
 
             await self._unbind_plugin(plugin_name, plugin.module_path)
 
+            # 删除插件文件夹
             try:
                 remove_dir(os.path.join(ppath, root_dir_name))
             except Exception as e:
                 raise Exception(
-                    f"移除插件成功，但是删除插件文件夹失败: {str(e)}。您可以手动删除该文件夹，位于 addons/plugins/ 下。"
+                    f"移除插件成功，但是删除插件文件夹失败: {e!s}。您可以手动删除该文件夹，位于 addons/plugins/ 下。",
                 )
 
+            # 删除插件配置文件
+            if delete_config and root_dir_name:
+                config_file = os.path.join(
+                    self.plugin_config_path,
+                    f"{root_dir_name}_config.json",
+                )
+                if os.path.exists(config_file):
+                    try:
+                        os.remove(config_file)
+                        logger.info(f"已删除插件 {plugin_name} 的配置文件")
+                    except Exception as e:
+                        logger.warning(f"删除插件配置文件失败: {e!s}")
+
+            # 删除插件持久化数据
+            # 注意：需要检查两个可能的目录名（plugin_data 和 plugins_data）
+            # data/temp 目录可能被多个插件共享，不自动删除以防误删
+            if delete_data and root_dir_name:
+                data_base_dir = os.path.dirname(ppath)  # data/
+
+                # 删除 data/plugin_data 下的插件持久化数据（单数形式，新版本）
+                plugin_data_dir = os.path.join(
+                    data_base_dir, "plugin_data", root_dir_name
+                )
+                if os.path.exists(plugin_data_dir):
+                    try:
+                        remove_dir(plugin_data_dir)
+                        logger.info(
+                            f"已删除插件 {plugin_name} 的持久化数据 (plugin_data)"
+                        )
+                    except Exception as e:
+                        logger.warning(f"删除插件持久化数据失败 (plugin_data): {e!s}")
+
+                # 删除 data/plugins_data 下的插件持久化数据（复数形式，旧版本兼容）
+                plugins_data_dir = os.path.join(
+                    data_base_dir, "plugins_data", root_dir_name
+                )
+                if os.path.exists(plugins_data_dir):
+                    try:
+                        remove_dir(plugins_data_dir)
+                        logger.info(
+                            f"已删除插件 {plugin_name} 的持久化数据 (plugins_data)"
+                        )
+                    except Exception as e:
+                        logger.warning(f"删除插件持久化数据失败 (plugins_data): {e!s}")
+
     async def _unbind_plugin(self, plugin_name: str, plugin_module_path: str):
         """解绑并移除一个插件。
 
         Args:
             plugin_name: 要解绑的插件名称
             plugin_module_path: 插件的完整模块路径
+
         """
         plugin = None
         del star_map[plugin_module_path]
@@ -714,10 +790,10 @@ class PluginManager:
                 del star_registry[i]
                 break
         for handler in star_handlers_registry.get_handlers_by_module_name(
-            plugin_module_path
+            plugin_module_path,
         ):
             logger.info(
-                f"移除了插件 {plugin_name} 的处理函数 {handler.handler_name} ({len(star_handlers_registry)})"
+                f"移除了插件 {plugin_name} 的处理函数 {handler.handler_name} ({len(star_handlers_registry)})",
             )
             star_handlers_registry.remove(handler)
 
@@ -728,11 +804,25 @@ class PluginManager:
         ]:
             del star_handlers_registry.star_handlers_map[k]
 
+        # llm_tools 中移除该插件的工具函数绑定
+        to_remove = []
+        for func_tool in llm_tools.func_list:
+            mp = func_tool.handler_module_path
+            if (
+                mp
+                and mp.startswith(plugin_module_path)
+                and not mp.endswith(("packages", "data.plugins"))
+            ):
+                to_remove.append(func_tool)
+        for func_tool in to_remove:
+            llm_tools.func_list.remove(func_tool)
+
         if plugin is None:
             return
 
         self._purge_modules(
-            root_dir_name=plugin.root_dir_name, is_reserved=plugin.reserved
+            root_dir_name=plugin.root_dir_name,
+            is_reserved=plugin.reserved,
         )
 
     async def update_plugin(self, plugin_name: str, proxy=""):
@@ -747,8 +837,7 @@ class PluginManager:
         await self.reload(plugin_name)
 
     async def turn_off_plugin(self, plugin_name: str):
-        """
-        禁用一个插件。
+        """禁用一个插件。
         调用插件的 terminate() 方法，
         将插件的 module_path 加入到 data/shared_preferences.json 的 inactivated_plugins 列表中。
         并且同时将插件启用的 llm_tool 禁用。
@@ -767,12 +856,18 @@ class PluginManager:
                 inactivated_plugins.append(plugin.module_path)
 
             inactivated_llm_tools: list = list(
-                set(await sp.global_get("inactivated_llm_tools", []))
+                set(await sp.global_get("inactivated_llm_tools", [])),
             )  # 后向兼容
 
             # 禁用插件启用的 llm_tool
             for func_tool in llm_tools.func_list:
-                if func_tool.handler_module_path == plugin.module_path:
+                mp = func_tool.handler_module_path
+                if (
+                    plugin.module_path
+                    and mp
+                    and plugin.module_path.startswith(mp)
+                    and not mp.endswith(("packages", "data.plugins"))
+                ):
                     func_tool.active = False
                     if func_tool.name not in inactivated_llm_tools:
                         inactivated_llm_tools.append(func_tool.name)
@@ -797,7 +892,8 @@ class PluginManager:
 
         if "__del__" in star_metadata.star_cls_type.__dict__:
             asyncio.get_event_loop().run_in_executor(
-                None, star_metadata.star_cls.__del__
+                None,
+                star_metadata.star_cls.__del__,
             )
         elif "terminate" in star_metadata.star_cls_type.__dict__:
             await star_metadata.star_cls.terminate()
@@ -814,8 +910,12 @@ class PluginManager:
 
         # 启用插件启用的 llm_tool
         for func_tool in llm_tools.func_list:
+            mp = func_tool.handler_module_path
             if (
-                func_tool.handler_module_path == plugin.module_path
+                plugin.module_path
+                and mp
+                and plugin.module_path.startswith(mp)
+                and not mp.endswith(("packages", "data.plugins"))
                 and func_tool.name in inactivated_llm_tools
             ):
                 inactivated_llm_tools.remove(func_tool.name)
@@ -824,8 +924,6 @@ class PluginManager:
 
         await self.reload(plugin_name)
 
-        # plugin.activated = True
-
     async def install_plugin_from_file(self, zip_file_path: str):
         dir_name = os.path.basename(zip_file_path).replace(".zip", "")
         dir_name = dir_name.removesuffix("-master").removesuffix("-main").lower()
@@ -836,7 +934,7 @@ class PluginManager:
         try:
             os.remove(zip_file_path)
         except BaseException as e:
-            logger.warning(f"删除插件压缩包失败: {str(e)}")
+            logger.warning(f"删除插件压缩包失败: {e!s}")
         # await self.reload()
         await self.load(specified_dir_name=dir_name)
 
@@ -857,10 +955,10 @@ class PluginManager:
 
         if os.path.exists(readme_path):
             try:
-                with open(readme_path, "r", encoding="utf-8") as f:
+                with open(readme_path, encoding="utf-8") as f:
                     readme_content = f.read()
             except Exception as e:
-                logger.warning(f"读取插件 {dir_name} 的 README.md 文件失败: {str(e)}")
+                logger.warning(f"读取插件 {dir_name} 的 README.md 文件失败: {e!s}")
 
         plugin_info = None
         if plugin:
